Colour - HDRI - TODO
====================

TODO
----

- colour_hdri (2 items in 2 files)

    - calibration (1 item in 1 file)

        - debevec1997.py

            - (159, 11) # TODO: Investigate if the normalisation value should account for the percentage of uncertain camera response functions values or be correlated to it and scaled accordingly. As an alternative of setting the uncertain camera response functions values to zero, it would be interesting to explore extrapolation as the camera response functions are essentially smooth. It is important to note that camera sensors are usually acting non linearly when reaching saturation level.

    - tonemapping (1 item in 1 file)

        - global_operators (1 item in 1 file)

            - operators.py

                - (464, 7) # TODO: Implement automatic *p* and *non-uniform* computations support.

About
-----

| **Colour - HDRI** by Colour Developers - 2013 - 2015
| Copyright © 2013 - 2015 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour-hdri <http://github.com/colour-science/colour-hdri>`_
